==> how-to-cook-1.2.0.tgz: package/tips/learn/学习腌.md <==
# 腌（肉）

## 注意

此处所描述的腌渍是食材烹饪前处理的步骤，并非制作咸肉或腌制香肠等成品

## 腌渍

在烹饪前腌制肉类是让肉类预先入味的常用方法。一般腌渍的对象是生肉。根据菜品的需求，可以自行确定肉类改刀的大小。

  例如炸鸡米花，鸡胸肉是在改刀为骰子大小的小块后放入碗中腌渍
  例如烤全羊，羊腿，半扇或整扇羊肉不必改刀即可用大量调味料涂抹在表面从而腌渍入味

根据菜品的不同，腌渍所选的调味料、辅料可以是任何种类。有时候为了不同的口味，辅料也可能需要预先处理。

## 腌渍基本概念

此处介绍的是正常口味的腌渍过程。

- 一般来说，肉量越大（比如一次性腌渍 5kg 鸡翅），体积越大（比如一整个羊腿），口味越重，则需要调味料和辅料越多
- 一般来说，计划腌渍的时间越长，使用的调味料和辅料越少
- 腌渍时应使用料均匀覆盖在所有的表面。如果是肉片、肉丝，应该用手尽量抓匀、搅匀。如果是整个羊腿，应该用手或刷子在表面刷匀
- 一般炒肉、炸肉需要提前腌渍。炒肉应该保证肉鲜嫩的口感，烹调往往需要大火且时间较短。短时间烹饪不容易入味时，提前腌渍就能弥补口味的不足

## 腌渍手法

- 细肉丝、薄肉片：由于肉质较脆弱，需要尽量轻柔。手指呈娃娃机钳子的形状，轻微抓匀腌料。然后向一个方向轻轻搅匀即可
- 肉丝、肉片、肉块：手法同上，但是力量可以稍大
- 鸡腿、鸡翅等大小：先在食材上改几道花刀。鸡翅根、鸡腿可以用刀扎对穿孔。然后先在碗里混合好腌料，在把食材放入料碗中裹匀
- 羊腿等大小：一般可以在肉较厚的位置扎对穿孔。然后腌料混合好后均匀涂抹在食材表面

## 腌渍容器及时间

- 选择能装下食材和腌料的容器即可。包括碗、盘子、托盘等。此时是开口腌渍，一般时间较短，常见 0.5-2 小时的腌渍时间。（烤）羊腿等也可以如此腌渍，但时间较长
- 可以选择足够大的食品密封袋腌渍。此时是封口腌渍，一般时间很长，例如隔夜腌渍，或腌渍不易入味的排骨等。常见 4 小时-隔夜。此时用料要稍微减少，防止成菜口感太重太咸

## 常用的腌渍用料

- 生抽：调酱香且带有咸味的底味。可用于几乎所有肉类
- 老抽：咸味并不强烈，但是易于染色。用于调底色和增香。一般不应大量使用防止产生豆腥味。可用于几乎所有红肉类（较少用），猪肝等可以多加
- 食盐：咸味但炒制后不带有酱香味。可用于所有肉类
- 白（砂）糖：调甜味（量大），也可以为肉增加鲜嫩的口感（量少）。可用于所有禽畜类肉类，但鱼类和海鲜并不常用。
- 红糖：调甜味和红糖特有的口感，口味比白糖略重。可用于几乎所有肉类（一般肉色较深或者成菜颜色较深）
- 蚝油：增加鲜、咸、甜的口味。一般用于红肉
- 白醋/米醋：增加酸的口味。较少使用
- 陈醋/香醋：不仅带有酸的口味，还能为菜品增香增色。香醋比较适合深色鱼类（尤其是烤鱼）
- 料酒：去腥增香。可用于几乎所有肉类。但白色肉类应该少用
- 黄酒：去腥增香，效果比料酒更好，香味比料酒更复杂。一般用于白肉类。红肉也可用，但是效果与料酒相当。
- 五香粉/十三香：为肉类增加香味，是最简单的复合香料。五香粉仅仅增加香味，十三香的香味比较独特，有辨识度。用此类香料腌渍应该控制用量。可用于几乎所有肉类，但鱼类和海鲜不常用
- 辣椒粉：辣椒粉分为很多种。不谈辣椒的种类，从研磨精细度划分有辣椒粉/辣椒面，辣椒碎等。除了为肉类增加辣味，还能为成菜配色。用辣椒腌渍的菜品应该避免辣椒过量。可用于几乎所有需要辣味底味的肉类，但烹调时间应该略加控制，防止辣椒味道变苦，或者颜色变深
- 孜然粉、小茴香粉：一般用磨粉作为腌料，不用颗粒，这样可以使肉类更容易入味。可用于几乎所有红肉和鸡肉
- X 椒粉：为肉类增加辛、辣、香、呛的口味。使用应该适量，防止盖过其他口味
  - 黑胡椒粉：口味辛、辣。可用于几乎所有红肉
  - 白胡椒粉：口味辛、香。比黑胡椒略弱，突出香味。可用于几乎所有肉类
  - 花椒粉：口味辛、呛。有花椒特殊的香味，比较有辨识度。可用于几乎所有肉类
- 豆瓣酱：为肉类增加豆类的酱香和咸味、辣味。可用于几乎所有红肉类
- 葱姜蒜：葱姜去腥增香，去除异味；蒜增加辛香味。葱可根据需要切段或者切片；姜一般切片，有些场景需要去皮；蒜可切片或切碎。葱姜不想出现在成菜中，或者口味需要较轻，可以将葱姜块放于有极少量清水的碗里挤压出汁，用葱姜水腌渍肉类。蒜一般不直接加入。可用于所有肉类
- 海鲜酱、虾酱等：为肉类增加鲜、咸味。海鲜酱口味偏甜，虾酱口味偏重。可用于几乎所有肉类，但使用场景不多
- 豆豉：为肉类增加发酵豆类的香味和咸味。可用于几乎所有红肉类，但是使用的并不多
- 生粉：即为淀粉。生粉是上浆的重要腌料。上浆越厚，或者需要口感越滑嫩，需要的生粉越多。可用于几乎所有肉类。`生粉可作为简易的油炸外衣使用（一般根据需要还需加入面粉等），此时一般不在腌渍时加入`
  - 玉米淀粉、土豆淀粉：粘性一般最大
  - 红薯淀粉：粘性略低
- 油：在腌渍时加入适量油进行油封，可以锁住水分和风味。如使用开口容器腌渍，且时间较长（例如在碗里），油封能极大程度保证肉质不变干或变柴。可用于几乎所有肉类。油封后炒制应略微减少底油，油炸则没有区别

## 几种较为通用的腌渍公式

- 牛肉：使用适量生抽，少量料酒，少量白砂糖腌渍。根据口味选用食盐（补充咸味），蚝油和极少量海鲜酱（蚝油牛肉），五香粉/十三香（洋葱炒牛肉）。慎用葱姜
- 鸡肉（包括鸡胸肉和鸡翅）：使用适量生抽，较少量白砂糖，少量料酒腌渍。根据口味选用食盐（补充咸味），五香粉/十三香（炸鸡米花），极少量老抽（香煎鸡翅中）
- 白色鱼肉：使用适量食盐，少量料酒/黄酒腌渍。根据口味选用海鲜酱/海鲜酱油/蒸鱼豉油（香煎带鱼），葱姜（水）（烤带皮鱼肉）
- 红色鱼肉：使用适量生抽，少量料酒腌渍。根据口味选用海鲜酱油/少量蒸鱼豉油（香煎三文鱼），红糖（北欧香烤三文鱼）
- 猪肝：使用适量生抽，适量料酒腌渍。根据口味选用生粉和适量老抽（滑炒猪肝），少量糖等

## 菜品实战示例

- 洋葱炒牛肉：以一人份的 150g 牛肉为例。牛肉应切片，成菜口感应嫩滑，需炒制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 5ml（约 1 汤匙）
  - 白砂糖 2.5-10g（约 1-4 茶匙，根据口味甜度选择）
  - 孜然粉 5g（约 2 茶匙）
  - 生粉 10-15g（约 1 小把）
  - 油 10ml（约 2 汤匙）
  - （可选）十三香 1g（约 0.5 茶匙）
  - （可选）黑胡椒粉 1g（约 0.5 茶匙）

- 蚝油牛肉：以一人份的 150g 牛肉为例。牛肉应切片，成才口感应嫩滑且上浆感足，此菜口感偏甜，需炒制
  - 生抽 5ml（约 1 汤匙）
  - 料酒 5ml（约 1 汤匙）
  - 蚝油 10-20ml（约 2-4 汤匙，根据口味咸度选择，蚝油比较咸）
  - 白砂糖 5-15g（约 2-6 茶匙，根据口味甜度选择）
  - 生粉 25-35g（约 1 大把）
  - 油 10ml（约 2 汤匙）

- 五香盐酥鸡：以一人份的 150g 鸡胸肉为例。鸡肉应切成骰子形状，需炸制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 2.5ml（约 0.5 汤匙）
  - 五香粉 5g（约 2 茶匙）或十三香 2.5-5g（约 1-2 茶匙）
  - （可选）孜然粉 1g（约 0.5 茶匙）
  - （可选）白胡椒粉 1g（约 0.5 茶匙）

- 蜜汁烤鸡翅：以一人份的 250g 带骨鸡翅中为例。鸡翅上应切几道花刀，成菜咸甜，但突出甜口，需烤制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 2.5ml（约 0.5 汤匙）
  - 白砂糖 5-15g（约 2-6 茶匙，根据口味甜度选择）
  - 蜂蜜/糖浆 10-20ml（约 2-4 汤匙，根据口味甜度选择。如白砂糖超过或等于 10g，建议只加入 10ml）
  - （可选）五香粉 2.5g（约 1 茶匙。不可用十三香）

- 香烤三文鱼：以一人份的 200g 去骨三文鱼排为例。鱼肉不应改刀，需烤箱烤制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 2.5ml（约 0.5 汤匙）
  - 红糖 10-20g（约 4-8 茶匙，根据口味甜度选择）
  - 意大利黑醋/镇江香醋 2.5-5ml（约 0.5-1 汤匙，根据口味酸度选择）
  - 肉豆蔻粉 2.5g（约 1 茶匙）
  - 百里香粉 1g（约 0.5 茶匙）
  - 姜粉 1g（约 0.5 茶匙）
  - 迷迭香粉 1-2g（约 0.5-1 茶匙）
  - （可选）白胡椒粉 1g（约 0.5 茶匙）
  - （可选）干辣椒碎 2.5-10g（约 1-4 茶匙，根据口味辣度选择）

==> how-to-cook-1.4.0.tgz: package/tips/learn/学习腌.md <==
# 腌（肉）

## 注意

此处所描述的腌渍是食材烹饪前处理的步骤，并非制作咸肉或腌制香肠等成品

## 腌渍

在烹饪前腌制肉类是让肉类预先入味的常用方法。一般腌渍的对象是生肉。根据菜品的需求，可以自行确定肉类改刀的大小。

  例如炸鸡米花，鸡胸肉是在改刀为骰子大小的小块后放入碗中腌渍
  例如烤全羊，羊腿，半扇或整扇羊肉不必改刀即可用大量调味料涂抹在表面从而腌渍入味

根据菜品的不同，腌渍所选的调味料、辅料可以是任何种类。有时候为了不同的口味，辅料也可能需要预先处理。

## 腌渍基本概念

此处介绍的是正常口味的腌渍过程。

- 一般来说，肉量越大（比如一次性腌渍 5kg 鸡翅），体积越大（比如一整个羊腿），口味越重，则需要调味料和辅料越多
- 一般来说，计划腌渍的时间越长，使用的调味料和辅料越少
- 腌渍时应使用料均匀覆盖在所有的表面。如果是肉片、肉丝，应该用手尽量抓匀、搅匀。如果是整个羊腿，应该用手或刷子在表面刷匀
- 一般炒肉、炸肉需要提前腌渍。炒肉应该保证肉鲜嫩的口感，烹调往往需要大火且时间较短。短时间烹饪不容易入味时，提前腌渍就能弥补口味的不足

## 腌渍手法

- 细肉丝、薄肉片：由于肉质较脆弱，需要尽量轻柔。手指呈娃娃机钳子的形状，轻微抓匀腌料。然后向一个方向轻轻搅匀即可
- 肉丝、肉片、肉块：手法同上，但是力量可以稍大
- 鸡腿、鸡翅等大小：先在食材上改几道花刀。鸡翅根、鸡腿可以用刀扎对穿孔。然后先在碗里混合好腌料，在把食材放入料碗中裹匀
- 羊腿等大小：一般可以在肉较厚的位置扎对穿孔。然后腌料混合好后均匀涂抹在食材表面

## 腌渍容器及时间

- 选择能装下食材和腌料的容器即可。包括碗、盘子、托盘等。此时是开口腌渍，一般时间较短，常见 0.5-2 小时的腌渍时间。（烤）羊腿等也可以如此腌渍，但时间较长
- 可以选择足够大的食品密封袋腌渍。此时是封口腌渍，一般时间很长，例如隔夜腌渍，或腌渍不易入味的排骨等。常见 4 小时-隔夜。此时用料要稍微减少，防止成菜口感太重太咸

## 常用的腌渍用料

- 生抽：调酱香且带有咸味的底味。可用于几乎所有肉类
- 老抽：咸味并不强烈，但是易于染色。用于调底色和增香。一般不应大量使用防止产生豆腥味。可用于几乎所有红肉类（较少用），猪肝等可以多加
- 食盐：咸味但炒制后不带有酱香味。可用于所有肉类
- 白（砂）糖：调甜味（量大），也可以为肉增加鲜嫩的口感（量少）。可用于所有禽畜类肉类，但鱼类和海鲜并不常用。
- 红糖：调甜味和红糖特有的口感，口味比白糖略重。可用于几乎所有肉类（一般肉色较深或者成菜颜色较深）
- 蚝油：增加鲜、咸、甜的口味。一般用于红肉
- 白醋/米醋：增加酸的口味。较少使用
- 陈醋/香醋：不仅带有酸的口味，还能为菜品增香增色。香醋比较适合深色鱼类（尤其是烤鱼）
- 料酒：去腥增香。可用于几乎所有肉类。但是使用需要注意：
  - 料酒本身的味道很浓，很容易掩盖食材本身的香味，对于腥味不浓郁的食材，可以考虑不用料酒来去腥。例如：牛肉，鱼肉和鸡肉。
  - 对于鸡肉，可以用白酒去代替料酒。
  - 对于牛肉，可以用姜葱水代替料酒。
  - 对于白色鱼肉，只需要清洗干净血丝和粘膜就不会有什么腥味了，建议不加料酒。
- 黄酒：去腥增香，效果比料酒更好，香味比料酒更复杂。一般用于白肉类。红肉也可用，但是效果与料酒相当。
- 五香粉/十三香：为肉类增加香味，是最简单的复合香料。五香粉仅仅增加香味，十三香的香味比较独特，有辨识度。用此类香料腌渍应该控制用量。可用于几乎所有肉类，但鱼类和海鲜不常用
- 辣椒粉：辣椒粉分为很多种。不谈辣椒的种类，从研磨精细度划分有辣椒粉/辣椒面，辣椒碎等。除了为肉类增加辣味，还能为成菜配色。用辣椒腌渍的菜品应该避免辣椒过量。可用于几乎所有需要辣味底味的肉类，但烹调时间应该略加控制，防止辣椒味道变苦，或者颜色变深
- 孜然粉、小茴香粉：一般用磨粉作为腌料，不用颗粒，这样可以使肉类更容易入味。可用于几乎所有红肉和鸡肉
- X 椒粉：为肉类增加辛、辣、香、呛的口味。使用应该适量，防止盖过其他口味
  - 黑胡椒粉：口味辛、辣。可用于几乎所有红肉
  - 白胡椒粉：口味辛、香。比黑胡椒略弱，突出香味。可用于几乎所有肉类
  - 花椒粉：口味辛、呛。有花椒特殊的香味，比较有辨识度。可用于几乎所有肉类
- 豆瓣酱：为肉类增加豆类的酱香和咸味、辣味。可用于几乎所有红肉类
- 葱姜蒜：葱姜去腥增香，去除异味；蒜增加辛香味。葱可根据需要切段或者切片；姜一般切片，有些场景需要去皮；蒜可切片或切碎。葱姜不想出现在成菜中，或者口味需要较轻，可以将葱姜块放于有极少量清水的碗里挤压出汁，用葱姜水腌渍肉类。蒜一般不直接加入。可用于所有肉类
- 海鲜酱、虾酱等：为肉类增加鲜、咸味。海鲜酱口味偏甜，虾酱口味偏重。可用于几乎所有肉类，但使用场景不多
- 豆豉：为肉类增加发酵豆类的香味和咸味。可用于几乎所有红肉类，但是使用的并不多
- 生粉：即为淀粉。生粉是上浆的重要腌料。上浆越厚，或者需要口感越滑嫩，需要的生粉越多。可用于几乎所有肉类。`生粉可作为简易的油炸外衣使用（一般根据需要还需加入面粉等），此时一般不在腌渍时加入`
  - 玉米淀粉、土豆淀粉：粘性一般最大
  - 红薯淀粉：粘性略低
- 油：在腌渍时加入适量油进行油封，可以锁住水分和风味。如使用开口容器腌渍，且时间较长（例如在碗里），油封能极大程度保证肉质不变干或变柴。可用于几乎所有肉类。油封后炒制应略微减少底油，油炸则没有区别

## 几种较为通用的腌渍公式

- 牛肉：使用适量生抽，少量料酒，少量白砂糖腌渍。根据口味选用食盐（补充咸味），蚝油和极少量海鲜酱（蚝油牛肉），五香粉/十三香（洋葱炒牛肉）。慎用葱姜
- 鸡肉（包括鸡胸肉和鸡翅）：使用适量生抽，较少量白砂糖，少量料酒腌渍。根据口味选用食盐（补充咸味），五香粉/十三香（炸鸡米花），极少量老抽（香煎鸡翅中）
- 白色鱼肉：使用适量食盐，少量料酒/黄酒腌渍。根据口味选用海鲜酱/海鲜酱油/蒸鱼豉油（香煎带鱼），葱姜（水）（烤带皮鱼肉）
- 红色鱼肉：使用适量生抽，少量料酒腌渍。根据口味选用海鲜酱油/少量蒸鱼豉油（香煎三文鱼），红糖（北欧香烤三文鱼）
- 猪肝：使用适量生抽，适量料酒腌渍。根据口味选用生粉和适量老抽（滑炒猪肝），少量糖等

## 菜品实战示例

- 洋葱炒牛肉：以一人份的 150g 牛肉为例。牛肉应切片，成菜口感应嫩滑，需炒制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 5ml（约 1 汤匙）
  - 白砂糖 2.5-10g（约 1-4 茶匙，根据口味甜度选择）
  - 孜然粉 5g（约 2 茶匙）
  - 生粉 10-15g（约 1 小把）
  - 油 10ml（约 2 汤匙）
  - （可选）十三香 1g（约 0.5 茶匙）
  - （可选）黑胡椒粉 1g（约 0.5 茶匙）

- 蚝油牛肉：以一人份的 150g 牛肉为例。牛肉应切片，成菜口感应嫩滑且上浆感足，此菜口感偏甜，需炒制
  - 生抽 5ml（约 1 汤匙）
  - 料酒 5ml（约 1 汤匙）
  - 蚝油 10-20ml（约 2-4 汤匙，根据口味咸度选择，蚝油比较咸）
  - 白砂糖 5-15g（约 2-6 茶匙，根据口味甜度选择）
  - 生粉 25-35g（约 1 大把）
  - 油 10ml（约 2 汤匙）

- 五香盐酥鸡：以一人份的 150g 鸡胸肉为例。鸡肉应切成骰子形状，需炸制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 2.5ml（约 0.5 汤匙）
  - 五香粉 5g（约 2 茶匙）或十三香 2.5-5g（约 1-2 茶匙）
  - （可选）孜然粉 1g（约 0.5 茶匙）
  - （可选）白胡椒粉 1g（约 0.5 茶匙）

- 蜜汁烤鸡翅：以一人份的 250g 带骨鸡翅中为例。鸡翅上应切几道花刀，成菜咸甜，但突出甜口，需烤制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 2.5ml（约 0.5 汤匙）
  - 白砂糖 5-15g（约 2-6 茶匙，根据口味甜度选择）
  - 蜂蜜/糖浆 10-20ml（约 2-4 汤匙，根据口味甜度选择。如白砂糖超过或等于 10g，建议只加入 10ml）
  - （可选）五香粉 2.5g（约 1 茶匙。不可用十三香）

- 香烤三文鱼：以一人份的 200g 去骨三文鱼排为例。鱼肉不应改刀，需烤箱烤制
  - 生抽 10ml（约 2 汤匙）
  - 料酒 2.5ml（约 0.5 汤匙）
  - 红糖 10-20g（约 4-8 茶匙，根据口味甜度选择）
  - 意大利黑醋/镇江香醋 2.5-5ml（约 0.5-1 汤匙，根据口味酸度选择）
  - 肉豆蔻粉 2.5g（约 1 茶匙）
  - 百里香粉 1g（约 0.5 茶匙）
  - 姜粉 1g（约 0.5 茶匙）
  - 迷迭香粉 1-2g（约 0.5-1 茶匙）
  - （可选）白胡椒粉 1g（约 0.5 茶匙）
  - （可选）干辣椒碎 2.5-10g（约 1-4 茶匙，根据口味辣度选择）
